import numpy as np
import matplotlib.pyplot as plt


from scipy.integrate import odeint
from pylab import *


def ode_model(z, t, beta, sigma, gamma, delta):
    S, E, I, R, D = z
    N = S + E + I + R + D
    dSdt = -beta*S*I/N
    dEdt = beta*S*I/N - sigma*E
    dIdt = sigma*E - (gamma+delta)*I 
    dRdt = gamma*I
    dDdt = delta*I
    return [dSdt, dEdt, dIdt, dRdt, dDdt]
    

def ode_solver(t, initial_conditions, params):
    initE, initI, initR, initD, initN = initial_conditions
    beta, sigma, gamma, delta = params
    initS = initN - (initE + initI + initR + initD)
    res = odeint(ode_model, [initS, initE, initI, initR, initD], t, args=(beta, sigma, gamma, delta))
    return res
    
days = 100
population = 100
deathRate = 0.0053
r_0 = 3
dayContagious = 7
dayIncubation = 5
daySick = 25
initial_conditions = [0, 1, 0, 0, population]    
params = [r_0/dayContagious, 1/dayIncubation, (1-deathRate)/daySick, deathRate/daySick]
tspan = np.arange(0, days, 1)
sol = ode_solver(tspan, initial_conditions, params)

S=sol[:,0]
E=sol[:,1]
I=sol[:,2]
R=sol[:,3]
D=sol[:,4]

l1 = plt.plot(S, label = "S")
l2 = plt.plot(E, label = "E")
l3 = plt.plot(I, label = "I")
l4 = plt.plot(R, label = "R")
l5 = plt.plot(D, label = "D")

plt.legend()
plt.xlabel("Days")
plt.ylabel("Population")
plt.show()



